dimFill property

double? dimFill
getter/setter pair

The position value to fill the domain dimension when dimCount is 1.

It is a normalized value of [0, 1].

If null, a default 0.5 is set, which means in the middle of the dimension.

Note for pie chart, the label radius position is controlled by PolarCoord.dimFill, labelPosition will not work.

Implementation

double? dimFill;