Selection class abstract

The specification of a selection.

A selection is a data query driven by Gestures. When a selection is triggered, data tuples become either selected or unselected states(At least one tuple is selected), thus may causing their aesthetic encodes change if Encode.updaters is defined.

See also:

Implementers

Constructors

Selection({Dim? dim, String? variable, Set<GestureType>? on, Set<GestureType>? clear, Set<PointerDeviceKind>? devices, int? layer})
Creates a selection.

Properties

clear ↔ Set<GestureType>?
Gesture types that will clear selections.
getter/setter pair
devices ↔ Set<PointerDeviceKind>?
The device kinds on which this selection is tiggered.
getter/setter pair
dim ↔ Dim?
Which diemsion of data values will be tested.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
layer ↔ int?
The layer of the selector mark.
getter/setter pair
on ↔ Set<GestureType>?
Gesture types that trigger this selection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variable ↔ String?
If set, all tuples sharing the same this variable value with the selected tuple, will also be selected.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override